@@ -4,7 +4,7 @@ use strict;
 use IO::Socket;
 use vars qw ($VERSION);
 
-$VERSION = $1 if('$Id: Proxy.pm,v 1.12 2011/02/07 16:02:52 cfaber Exp $' =~ /,v ([\d.]+) /);
+$VERSION = $1 if('$Id: Proxy.pm,v 1.3 2004/07/04 00:13:18 cfaber Exp $' =~ /,v ([\d.]+) /);
 
 =head1 NAME
 
@@ -16,17 +16,7 @@ The Net::Whois::Proxy library is an easy to use recursive whois client library t
 
 =head1 SYNOPSIS
 
- use Net::Whois::Proxy;
- my $whois = new Net::Whois::Proxy;
-
- my $record = $whois->whois('EXAMPLE.COM');
-
- print $record;
-
- exit;
-
-
-Also see the whois.pl example script provided with the library distrobution
+See the whois.pl example script provided with the library.
 
 =head1 METHODS
 
@@ -148,14 +138,14 @@ sub new {
  my ($class, %opts) = @_;
 
  my $self = bless {
-	debug			=> $opts{debug},
-	stacked_results		=> $opts{stacked_results},
-	clean_stack		=> $opts{clean_stack},
-	master_ip_whois		=> $opts{master_ip_whois} || 'whois.arin.net',
-	master_ip_port		=> $opts{master_ip_port} || 43,
-	master_whois		=> $opts{master_whois} || 'whois.internic.net',
-	master_port		=> $opts{master_port} || 43,
-	query_timeout		=> $opts{query_timeout} || 10
+	debug		=> $opts{debug},
+	stacked_results	=> $opts{stacked_results},
+	clean_stack	=> $opts{clean_stack},
+	master_ip_whois	=> $opts{master_ip_whois} || 'whois.arin.net',
+	master_ip_port	=> $opts{master_ip_port} || 43,
+	master_whois	=> $opts{master_whois} || 'rs.internic.net',
+	master_port	=> $opts{master_port} || 43,
+	query_timeout	=> $opts{query_timeout} || 10
  }, $class;
 
  $self->{master_domain_whois} = ($opts{master_domain_whois} || $self->{master_whois});
@@ -178,7 +168,7 @@ If the string provided is an IPv6 address preform an whois query on it.
 
  Example:
 
- print $whois->whois("2001:4830:100:20::6");
+ print $whois->whois("3ffe:b80:138c:1::59");
 
 If the string provided is an IPv4 address preform an whois query on it.
 
@@ -203,6 +193,7 @@ If the string provided starts with 'convert' and a dotted quad IPv4 address or l
 
 sub whois {
  my ($self, $in) = @_;
+
  if((my $ip = $self->convert_ipv4($in))){     
         return $self->whois_ipv4($ip);      
  } elsif($in =~ /^[a-f0-9][a-f0-9][a-f0-9][a-f0-9]:/){
@@ -333,35 +324,17 @@ sub whois_ipv4 {
  );
 
  # If we're not querying ARIN right off the bat then add it to our hints list.
+
  $server || ($server = $self->{master_ip_whois});
 
- if($server !~ /whois\.arin\.net/i){
+ if($server !~ /whois.arin.net/i){
 	 $hints{'whois.arin.net'}->{port} = 43;
 	 $hints{'whois.arin.net'}->{regexps} = ['/IANA-NETBLOCK/'];
  }
  
  
- my $data = $self->_query_whois($ip, $server, $port || $self->{master_ip_port}, $self->{master_timeout}) || return;
+ my $data = $self->_query_whois($ip, $server, $port || $self->{master_ip_port}, $self->{master_timeout}) || return undef;
 
- # See if ``ReferralServer'' exists in the CDIR
- if($data =~ /ReferralServer\:\s*(?:whois:\/\/)?([A-Za-z0-9:.-]+)/){
-	my ($wi, $po) = split(/:/, $1, 2);
-	if($po !~ /^\d+$/ || !$po){
-		$po = ($self->{master_port} ? $self->{master_port} : 43);
-	}
-
-	$self->_pd("ReferralServer Match: $wi:$po", caller);
-	my $data2 = $self->_query_whois($ip, $wi, $po, $self->{master_timeout}) || return;
-
-	if($self->{stacked_results}){
-		$self->_pd("Stacking results", caller);
-		return (!$self->{clean_stack} ? 'QUERY_0: ' . $server : undef) . "\n" . $data . "\n" . (!$self->{clean_stack} ? 'QUERY_1: ' . "$wi\:$po" : "") . "\n" . $data2;
-	} else {
-		return ($data2 ? $data2 : $data);
-	}
- }
-
-	
  WHOIS: for my $whoisd (keys %hints){
 	$self->_pd($whoisd, caller);
 	HINT: for my $re (@{$hints{$whoisd}->{regexps}}){
@@ -524,7 +497,7 @@ Preform a recursive whois lookup on a fully qualified domain name (FQDN), Option
 
 =cut
 
-sub whois_domain {
+sub domain_whois {
  my ($self, $domain, $server, $port, $timeout) = @_;
  my $nic;
 
@@ -561,8 +534,7 @@ Attempt to determin if an IPv4 address is syntaxually valid.
 
 sub check_ipv4 {
  my ($self, @ip) = (shift, split(/\./, shift, 4));
-
- if(!$ip[0] || $ip[-1] !~ /\d/ || $ip[0] > 255 || $ip[0] !~ /^\d+$/){
+ if(!$ip[0] || $ip[0] > 255 || $ip[0] !~ /^\d+$/){
 	return $self->_seterrstr("Invalid IPv4 address");
  } else {
 	for my $i (1 .. 3){
@@ -612,28 +584,18 @@ sub whois_raw {
 sub _query_whois {
  my ($self, $data, $serv, $port, $timeout) = @_;
  my $sock;
-
- $self->{master_timeout} ||= 10;
-
- $port ||= $self->{master_port};
- $serv ||= $self->{master_serv};
- $timeout ||= $self->{master_timeout};
-
  $self->_pd("Attempting to connect to: $serv:$port (to: $timeout)", caller);
-
- $SIG{ALRM} = sub { die 'timeout'; };
  eval {
+	$SIG{ARLM} = sub { die 'timeout'; };
 	alarm(($timeout || $self->{master_timeout}) + 5);
 	$sock = IO::Socket::INET->new(
 		Proto		=> 'tcp',
 		PeerAddr	=> $serv || $self->{master_whois},
 		PeerPort	=> $port || $self->{master_port},
-		Timeout		=> $timeout || $self->{master_timeout}
+		Timeout	=> $timeout || $self->{master_timeout}
 	) || die "Unable to create socket $!";
+	alarm(0);
  };
-
- alarm(0);
-
  if($@ =~ /timeout/){
 	$self->_pd("Timed out!", caller);
 	return $self->_seterrstr("Connection to " . ($serv || $self->{master_whois}) . ':' . ($port || $self->{master_port}) . " was refused.");
@@ -692,7 +654,7 @@ __END__
 
 Colin Faber <cfaber@fpsn.net> http://www.fpsn.net
 
-=head1 LICENSE
+=head1 COPYRIGHT
 
 (C) Colin Faber All rights reserved.  This license may be used under the terms of Perl it self.
 
